import * as prompts from "@clack/prompts";
import { doesRepositoryExist } from "../doesRepositoryExist.js";
import { filterPromptCancel } from "../prompts.js";
async function ensureRepositoryExists(octokit, options) {
  let { createRepository, repository } = options;
  while (octokit) {
    if (await doesRepositoryExist(octokit, options)) {
      return { octokit, repository };
    }
    const selection = createRepository ? "create" : filterPromptCancel(
      await prompts.select({
        message: `Repository ${options.repository} doesn't seem to exist under ${options.owner}. What would you like to do?`,
        options: [
          { label: "Create a new repository", value: "create" },
          {
            label: "Switch to a different repository name",
            value: "different"
          },
          {
            label: "Keep changes local",
            value: "local"
          },
          { label: "Bail out and maybe try again later", value: "bail" }
        ]
      })
    );
    createRepository = false;
    switch (selection) {
      case "bail":
        return {};
      case "create":
        await octokit.rest.repos.createUsingTemplate({
          name: repository,
          owner: options.owner,
          template_owner: "JoshuaKGoldberg",
          template_repo: "create-typescript-app"
        });
        return { octokit, repository };
      case "different":
        const newRepository = filterPromptCancel(
          await prompts.text({
            message: `What would you like to call the repository?`
          })
        );
        if (!newRepository) {
          return {};
        }
        repository = newRepository;
        break;
      case "local":
        octokit = void 0;
        break;
    }
  }
  return { octokit, repository };
}
export {
  ensureRepositoryExists
};
//# sourceMappingURL=ensureRepositoryExists.js.map